docx\_parser\_converter.docx\_to\_txt.txt\_generator module
===========================================================

.. automodule:: docx_parser_converter.docx_to_txt.txt_generator
   :members:
   :undoc-members:
   :show-inheritance:
